@@ -1,13 +1,11 @@
+from http import HTTPStatus
 from requests.auth import HTTPBasicAuth
 from urllib.parse import parse_qsl
 
 from django.utils.http import urlencode
 
 from allauth.socialaccount.adapter import get_adapter
-from allauth.socialaccount.providers.oauth2.client import (
-    OAuth2Client,
-    OAuth2Error,
-)
+from allauth.socialaccount.providers.oauth2.client import OAuth2Client, OAuth2Error
 
 
 class NotionOAuth2Client(OAuth2Client):
@@ -36,7 +34,7 @@ class NotionOAuth2Client(OAuth2Client):
             )
         )
         access_token = None
-        if resp.status_code in [200, 201]:
+        if resp.status_code in [HTTPStatus.OK, HTTPStatus.CREATED]:
             try:
                 access_token = resp.json()
             except ValueError:
